@@ -1,3 +1,8 @@
+# -*- coding: utf-8 -*-
+
+# This file is part of the Ingram Micro Cloud Blue Connect connect-cli.
+# Copyright (c) 2019-2020 Ingram Micro. All Rights Reserved.
+
 import click
 import requests
 
@@ -9,6 +14,40 @@ from cnctcli.api.utils import (
 )
 
 
+def get_units(endpoint, api_key):
+    results = []
+
+    has_more = True
+    limit = 100
+    offset = 0
+
+    while has_more:
+        res = requests.get(
+            f'{endpoint}/settings/units',
+            params={'limit': limit, 'offset': offset},
+            headers=get_headers(api_key),
+        )
+        if res.status_code == 200:
+            page = res.json()
+            results.extend(page)
+            has_more = len(page) == 100
+            continue
+        handle_http_error(res)
+    return results
+
+
+def create_unit(endpoint, api_key, data):
+    res = requests.post(
+        f'{endpoint}/settings/units',
+        headers=get_headers(api_key),
+        json=data,
+    )
+    if res.status_code == 201:
+        return res.json()
+
+    handle_http_error(res)
+
+
 def get_products(endpoint, api_key, query, limit, offset):
     url = f'{endpoint}/products'
     if query:
@@ -113,3 +152,14 @@ def update_item(endpoint, api_key, product_id, item_id, data):
     )
     if res.status_code != 200:
         handle_http_error(res)
+
+    return res.json()
+
+
+def delete_item(endpoint, api_key, product_id, item_id):
+    res = requests.delete(
+        f'{endpoint}/products/{product_id}/items/{item_id}',
+        headers=get_headers(api_key),
+    )
+    if res.status_code != 204:
+        handle_http_error(res)
